Perform a Hermite interpolation across four values with `t` in the [0;1] range between `y1` and `y2`. The `tension` and `bias` parameters can be used to control the shape of underlying interpolation curve.

See [LinearInterpolate], [CosineInterpolate] and [CubicInterpolate].